<?php
/**
 * Nützliche globale Funktionen.
 *
 * @author   Roland Rusch, FiMA Informatik AG <roland.rusch@fima.ch>
 */



/**
 * Berechnet eine möglichst eindeutige UUID.
 * @return UUID
 */
function uuid()
//{{{
{
    // The field names refer to RFC 4122 section 4.1.2
    return sprintf('%04x%04x-%04x-%03x4-%04x-%04x%04x%04x',
        mt_rand(0, 65535), mt_rand(0, 65535), // 32 bits for "time_low"
        mt_rand(0, 65535), // 16 bits for "time_mid"
        mt_rand(0, 4095),  // 12 bits before the 0100 of (version) 4 for "time_hi_and_version"
        bindec(substr_replace(sprintf('%016b', mt_rand(0, 65535)), '01', 6, 2)),
            // 8 bits, the last two of which (positions 6 and 7) are 01, for "clk_seq_hi_res"
            // (hence, the 2nd hex digit after the 3rd hyphen can only be 1, 5, 9 or d)
            // 8 bits for "clk_seq_low"
        mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(0, 65535) // 48 bits for "node"  
    );  
}
//}}}

/**
 * Prüft, ob der angegebene String eine UUID darstellt.
 * @param $str String
 * @return bool
 */
function IsUuid($str)
//{{{
{
	$ret=preg_match('/^[a-f0-9]{8}\-[a-f0-9]{4}\-[a-f0-9]{4}\-[a-f0-9]{4}\-[a-f0-9]{12}$/i', $str);
	return ($ret==1);
}
//}}}

/**
 * Sendet eine Datei (auch grosse) an den Browser.
 * @param $path Pfad
 * @return bool
 */
function sendFile($path)
//{{{
{
	session_write_close();
	ob_end_clean();
	if (!is_file($path) || connection_status()!=0)
		return(FALSE);

	//to prevent long file from getting cut off from     //max_execution_time

	set_time_limit(0);

	$name=basename($path);

	//filenames in IE containing dots will screw up the
	//filename unless we add this

	if (strstr($_SERVER['HTTP_USER_AGENT'], "MSIE"))
		$name = preg_replace('/\./', '%2e', $name, substr_count($name, '.') - 1);

	//required, or it might try to send the serving     //document instead of the file

	header("Cache-Control: ");
	header("Pragma: ");
	header("Content-Type: application/octet-stream");
	header("Content-Length: " .(string)(filesize($path)) );
	header('Content-Disposition: attachment; filename="'.$name.'"');
	header("Content-Transfer-Encoding: binary\n");

	if($file = fopen($path, 'rb')){
		while( (!feof($file)) && (connection_status()==0) ){
			print(fread($file, 1024*8));
			flush();
		}
		fclose($file);
	}
	return((connection_status()==0) and !connection_aborted());
}
//}}}


/**
 * Gibt die microtime() mikrosekunden zurück.
 * @return Microtime als float
 */
function uTime()
//{{{
{
	list($usec, $sec) = explode(" ",microtime()); 
	return ((float)$usec + (float)$sec)*(float)1000; 
}
//}}}


function log_msg($str)
{
	/*
	$logs=new Logs();
	$d=array(
		'time' => new Zend_Db_Expr('NOW()'),
		'message' => $str
	);
	$log=$logs->createRow($d);
	$log->save();
	*/
	return log_msg_old($str);
}


/**
 * Schreibt die Meldung in das Log-File.
 * @param $str Meldung
 */
function log_msg_old($str)
{
	$ts=date('Y-m-d H:i:s');
	$lines=explode("\n", $str);
	$i=0;
	$aMsgs=array();
	foreach($lines as $lnum => $lstr) {
		if( $lstr != "" ) {
			$msg=$ts.' '.$lstr."";
			error_log($msg, 0);
			$aMsgs[]=$msg;
			$i++;
		}
	}
	return implode("\n", $aMsgs);
}


/**
 * Schreibt die Meldung in stdout.
 * @param $str Meldung
 */
function echo_msg($str)
//{{{
{
	$ts=date('Y-m-d H:i:s');
	$lines=explode("\n", $str);
	$i=0;
	foreach($lines as $lnum => $lstr) {
		if( $lstr != "" ) {
			//$msg=$ts.' '.$lstr."";
			$msg=$lstr."";
			echo($msg . "\n");
			$i++;
		}
	}
}
//}}}


/**
 * Rundet Schweizer Franken - auf 0.05.
 * @param $num Zahl
 * @return Text
 */
function round_CHF($num, $runden5=true)
{
	if($runden5) $num=round($num * 20, 0) / 20;
	return number_format($num, 2, '.', "'");
}


/**
 * Wandelt CR und LF in XML Entities um
 * @param $string String
 * @return Text
 */
function xmlnl($string)
//{{{
{
	$trans[chr(10)]='&#x000A;';
	$trans[chr(13)]='&#x000D;';
	return strtr($string, $trans);
}
//}}}


/**
 * Ersetzt die ASCII-zeichen >127 durch die XML Entities.
 * @param $string Text
 * @param $quote_style Quotes
 * @return Text
 */
function xmlentities($string, $quote_style=ENT_QUOTES)
{
	$config=Bootstrap::$registry->configuration->general;
	$encoding=isset($config->db->encoding) ? $config->db->encoding : 'latin1';
	if($encoding == 'utf8') return htmlentities(stripslashes($string), $quote_style, 'UTF-8');

	$trans = get_html_translation_table(HTML_ENTITIES, $quote_style);
	foreach ($trans as $key => $value) {
		$trans[$key] = '&#x'.str_pad(strtoupper(base_convert(ord($key), 10, 16)), 4, "0", STR_PAD_LEFT).';';
	}
	// dont translate the '&' in case it is part of &xxx;
	$trans[chr(38)] = '&';
//	$trans["'"] = '&#x2019;';  // UNICODE
//	$trans['"'] = '&#x201D;';  // UNICODE
	$trans["'"] = '&#x0027;';
	$trans['"'] = '&#x0022;';

//   }
	// after the initial translation, _do_ map standalone '&' into '&#38;'
	// UIUIUIUI ganz dreckig (== tidy)
	return preg_replace("/&(?![A-Za-z]{0,4}\w{2,3};|#[0-9]{2,5};|#x[0-9a-fA-F]{2,4};)/","&#x0026;" , strtr($string, $trans));
}


/**
 * Wandelt UTF8 und Entities zurück in Latin1, falls nötig.
 * @param $string Text
 * @return Text
 */
function unxmlentities($string)
//{{{
{
	$config=Bootstrap::$registry->configuration->general;
	$encoding=isset($config->db->encoding) ? $config->db->encoding : 'latin1';
	if($encoding == 'utf8') return $string;

	return utf8_decode($string);
}
//}}}



