<?php


/**
 * Callback für die weitere Bearbeitung der zurückgegebenen Daten.
 * @param array $meta Informationen über das Feld von sqlsrv_field_metadata()
 * @param string $name Name des Datenbankfeldes
 * @param string $value Feldinhalt. Original, wie von der Datenbank geliefert
 * @param array $row Referenz auf die Zeile im resultierenden Array
 * @return string
 */
function callbackdummy($meta, $name, $value, &$row)
{
	return $row[$name];
}



/**
 * Wandelt das Resultat in ein PHP Array um.
 * @param mixed $stmt
 * @return array
 */
function makeArrayFromStmt($stmt, $callback=null)
{
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName=$ArrFields[$i]['Name'];
			$nameCounter=0;
			while( isset($tmpArray[$SpaltenName]) )
			{
				$nameCounter++;
				$SpaltenName=$ArrFields[$i]['Name'] . '#' . $nameCounter;
			}
			$SpaltenWert = $row[$i];
			
			// SQL_BINARY (-2), SQL_VARBINARY (-3), SQL_LONGVARBINARY (-4) 
			if( !in_array( $ArrFields[$i]['Type'], [-2, -3, -4] ) )
				$tmpArray[$SpaltenName] = $SpaltenWert;
			else $tmpArray[$SpaltenName] = base64_encode($SpaltenWert);
			
			if( $callback !== null ) $tmpArray[$SpaltenName]=$callback($ArrFields[$i], $SpaltenName, $SpaltenWert, $tmpArray);
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}
	
	return $ArrRS;
}



/**
 * Wandelt das Array in einen JSON-String um.
 * @param array $ArrRS
 * @return string
 */
function makeJsonFromArray($ArrRS)
{
	return json_encode($ArrRS, JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES | JSON_PARTIAL_OUTPUT_ON_ERROR);
}



/**
 * Wandelt das Resultat in einen JSON-String um.
 * @param mixed $stmt
 * @return string
 */
function makeJsonFromStmt($stmt, $callback=null)
{
	return makeJsonFromArray(makeArrayFromStmt($stmt, $callback));
}



