<?php
require_once('globalfunctions.inc.php');
require_once('makeArrayFromStmt.php');
require_once('mssqlFunctions.php');


$e->register('createOrUpdateAdresse', [
		'data' => 'string',
	],
	['return' => 'string'],
	'Erstellt oder aktualisiert eine Adresse.'
);


/**
 * Erstellt oder aktualisiert eine Kontaktadresse.
 * @param string $data
 * @return string
 */
function createOrUpdateAdresse($data)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($data="' . $data . '")' );
	
	$data=json_decode($data);
	if(!is_object($data)) die(log_msg( __FUNCTION__ . '(): $data ist kein Array.' ));
	unset($data->AngelegtAm);
	unset($data->AngelegtVon);
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	$filter_ADRESS=mssqlTableFields('ADRESS', $conn);
	
	// Adresstyp prüfen
	if( !isset($data->Adresstyp) || empty($data->Adresstyp) )
		throw new Exception("Das Feld 'Adresstyp' ist nicht gesetzt.");
	// Handelt es sich wirklich um eine Lieferadresse?
	if( !in_array(substr($data->Adresstyp, 0, 3), ['KUL', 'INL']) )
		throw new \Exception("Die ADRESS #{$erpId}# ist keine Lieferadresse eines Kunden oder Interessenten.");
		
	log_msg('$data=' . print_r($data, true));
	
	
	$ADRESS_ID=isset($data->ADRESS_ID) ? $data->ADRESS_ID : null;
	
	if( $ADRESS_ID )
	{
		log_msg( __FUNCTION__ . "(): Adresse mit erpID #{$ADRESS_ID}# besteht bereits.");
		$sql = "UPDATE ADRESS
					SET " . makeMssqlSetlist($data, $filter_ADRESS) . "
					WHERE ADRESS_ID='{$ADRESS_ID}'";
		
		//log_msg('CRM_ADRESSEN SQL=' . $sql);
		// SQL-Abrage starten
		$stmt = sqlsrv_query( $conn, $sql );
		if(!$stmt) die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
		
		
	} else
	{
		log_msg( __FUNCTION__ . '(): Adresse wird neu angelegt.');
		$data->AngelegtAm=$data->BearbeitetAm;
		$data->AngelegtVon=$data->BearbeitetVon;
		$sql = "INSERT INTO ADRESS
					" . makeMssqlFieldlist($data, $filter_ADRESS) . "
					VALUES " . makeMssqlValuelist($data, $filter_ADRESS) . ";
					SELECT SCOPE_IDENTITY() AS LAST_INSERT_ID;";
		
		//log_msg('CRM_ADRESSEN SQL=' . $sql);
		// SQL-Abrage starten
		$stmt = sqlsrv_query( $conn, $sql );
		if(!$stmt) die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
		
		// ID ermitteln
		$ADRESS_ID=mssqlLastInsertId($stmt);
		
	}
	
	
	// Adresse suchen
	$aAdressen=json_decode(getAdressByErpId($ADRESS_ID));
	if(count($aAdressen) != 1) throw new Exception("Adresse mit erpID #{$ADRESS_ID}# nicht gefunden.");
	$adresse=$aAdressen[0];
	
	
	// JSON Array zurückgeben
	return makeJsonFromArray($adresse);
}



