<?php

require_once('globalfunctions.inc.php');
require_once('makeArrayFromStmt.php');
require_once('mssqlFunctions.php');


$e->register(
    'createOrUpdateKontaktadresse',
    [
        'data' => 'string',
    ],
    ['return' => 'string'],
    'Erstellt oder aktualisiert eine Kontaktadresse.'
);


/**
 * Erstellt oder aktualisiert eine Kontaktadresse.
 *
 * @param string $data
 *
 * @return string
 * @throws Exception
 */
function createOrUpdateKontaktadresse($data)
{
    global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
    
    log_msg(__FUNCTION__ . '($data="' . $data . '")');
    
    $data = json_decode($data);
    if (!is_object($data)) {
        die(log_msg(__FUNCTION__ . '(): $data ist kein Array.'));
    }
    unset($data->AngelegtAm);
    unset($data->AngelegtVon);
    
    $serverName = $mssqlServer . "\\" . $mssqlInstanz;
    $connectionInfo = ["Database" => $mssqlDB, "UID" => $mssqlUser, "PWD" => $mssqlPass, "CharacterSet" => "UTF-8"];
    $conn = sqlsrv_connect($serverName, $connectionInfo);
    if (!$conn) {
        die(log_msg('MSSQL Error: ' . print_r(sqlsrv_errors(), true)));
    }
    
    $filter_CRM_ADRESSEN = mssqlTableFields('CRM_ADRESSEN', $conn);
    $CRM_ADRESSEN_ID = isset($data->CRM_ADRESSEN_ID) ? $data->CRM_ADRESSEN_ID : null;
    
    
    if ($CRM_ADRESSEN_ID) {
        log_msg(__FUNCTION__ . "(): Kontaktadresse mit erpID #{$CRM_ADRESSEN_ID}# besteht bereits.");
        
        // LOCK setzen, damit die Änderung nicht wieder ins CRM synchonisiert wird
        $syncEntryCrmAdressen = setSyncEntry('LOCK', 'CRM_ADRESSEN', $CRM_ADRESSEN_ID);
        
        $sql = "UPDATE CRM_ADRESSEN
                    SET " . makeMssqlSetlist($data, $filter_CRM_ADRESSEN) . "
                    WHERE CRM_ADRESSEN_ID='{$CRM_ADRESSEN_ID}'";
        
        // SQL-Abfrage starten
        $stmt = sqlsrv_query($conn, $sql);
        if (!$stmt) {
            die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r(sqlsrv_errors(), true)));
        }
        
        unsetSyncEntry('', 'CRM_ADRESSEN', $CRM_ADRESSEN_ID);
        
    } else {
        log_msg(__FUNCTION__ . '(): Kontaktadresse wird neu angelegt.');
        $data->AngelegtAm = $data->BearbeitetAm;
        $data->AngelegtVon = $data->BearbeitetVon;
        $sql = "INSERT INTO CRM_ADRESSEN
                    " . makeMssqlFieldlist($data, $filter_CRM_ADRESSEN) . "
                    VALUES " . makeMssqlValuelist($data, $filter_CRM_ADRESSEN) . ";
                    SELECT SCOPE_IDENTITY() AS LAST_INSERT_ID;";
        
        // SQL-Abrage starten
        $stmt = sqlsrv_query($conn, $sql);
        if (!$stmt) {
            die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r(sqlsrv_errors(), true)));
        }
        
        // ID ermitteln
        $CRM_ADRESSEN_ID = mssqlLastInsertId($stmt);
    }
    
    
    // aktuelle Kontaktadresse holen
    $aKontaktadressen = json_decode(getKontaktadresseByErpId($CRM_ADRESSEN_ID));
    if (count($aKontaktadressen) != 1) {
        throw new Exception("Kontaktadresse mit erpID #{$CRM_ADRESSEN_ID}# nicht gefunden.");
    }
    $kontaktadresse = $aKontaktadressen[0];
    
    // Liste der Kunden, die im ERP mit dem Kontakt verknüpft sind
    $kundenErpIds_Erp = array_map(
        function ($kundeErpId) {
            return $kundeErpId;
        },
        array_filter(explode(';', $kontaktadresse->KUNDEN_IDs))
    );
    // Liste der Kunden, die im CRM mit dem Kontakt verknüpft sind
    $kundenErpIds_Crm = array_map(
        function ($kundeErpId) {
            return $kundeErpId;
        },
        array_filter(explode(';', $data->KUNDEN_IDs))
    );
    // Differenzen evaluieren
    $kundenErpIdsToAdd = array_diff($kundenErpIds_Crm, $kundenErpIds_Erp);
    $kundenErpIdsToRemove = array_diff($kundenErpIds_Erp, $kundenErpIds_Crm);

// 	log_msg('$kundenErpIds_Erp=' . var_export($kundenErpIds_Erp, true));
// 	log_msg('$kundenErpIds_Crm=' . var_export($kundenErpIds_Crm, true));
// 	log_msg('$kundenErpIdsToAdd=' . var_export($kundenErpIdsToAdd, true));
    // Verknüpfungen hinzufügen
    foreach ($kundenErpIdsToAdd as $erpId) {
        $hauptobjekte = json_decode(getKundeByErpId($erpId));
        if (count($hauptobjekte) == 1) {
            $hauptobjekt = $hauptobjekte[0];
        }
        if (!$hauptobjekt) {
            throw new Exception("Hauptobjekt mit KUNDEN_ID #{$erpId}# nicht gefunden.");
        }
        $hauptadresse = $hauptobjekt->CRM_AdressenID;
        $sql = "INSERT INTO CRM_PERSONENLINK
                    (\"PersonID\", \"AdresseID\", \"AngelegtAm\")
                    VALUES(
                        '{$CRM_ADRESSEN_ID}',
                        '{$hauptadresse}',
                        getdate()
                    );";
        $stmt = sqlsrv_query($conn, $sql);
        if (!$stmt) {
            die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r(sqlsrv_errors(), true)));
        }
    };
    // Verknüpfungen löschen
// 	log_msg('$kundenErpIdsToRemove=' . var_export($kundenErpIdsToRemove, true));
    foreach ($kundenErpIdsToRemove as $erpId) {
        $hauptobjekte = json_decode(getKundeByErpId($erpId));
        if (count($hauptobjekte) == 1) {
            $hauptobjekt = $hauptobjekte[0];
        }
        if (!$hauptobjekt) {
            throw new Exception("Hauptobjekt mit KUNDEN_ID #{$erpId}# nicht gefunden.");
        }
        $hauptadresse = $hauptobjekt->CRM_AdressenID;
        $sql = "DELETE FROM CRM_PERSONENLINK
                    WHERE \"PersonID\"='{$CRM_ADRESSEN_ID}'
                    AND \"AdresseID\"='{$hauptadresse}'
                    ;";
        $stmt = sqlsrv_query($conn, $sql);
        if (!$stmt) {
            die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r(sqlsrv_errors(), true)));
        }
    };
    
    
    // Liste der Interessenten, die im ERP mit dem Kontakt verknüpft sind
    $interessentenErpIds_Erp = array_map(
        function ($interessentErpId) {
            return $interessentErpId;
        },
        array_filter(explode(';', $kontaktadresse->INTERESS_IDs))
    );
    // Liste der Interessenten, die im CRM mit dem Kontakt verknüpft sind
    $interessentenErpIds_Crm = array_map(
        function ($interessentErpId) {
            return $interessentErpId;
        },
        array_filter(explode(';', $data->INTERESS_IDs))
    );
    // Differenzen evaluieren
    $interessentenErpIdsToAdd = array_diff($interessentenErpIds_Crm, $interessentenErpIds_Erp);
    $interessentenErpIdsToRemove = array_diff($interessentenErpIds_Erp, $interessentenErpIds_Crm);


// 	log_msg('$interessentenErpIds_Erp=' . var_export($interessentenErpIds_Erp, true));
// 	log_msg('$interessentenErpIds_Crm=' . var_export($interessentenErpIds_Crm, true));
// 	log_msg('$interessentenErpIdsToAdd=' . var_export($interessentenErpIdsToAdd, true));
    // Verknüpfungen hinzufügen
    foreach ($interessentenErpIdsToAdd as $erpId) {
        $hauptobjekte = json_decode(getInteressentByErpId($erpId));
        if (count($hauptobjekte) == 1) {
            $hauptobjekt = $hauptobjekte[0];
        }
        if (!$hauptobjekt) {
            throw new Exception("Hauptobjekt mit INTERESS_ID #{$erpId}# nicht gefunden.");
        }
        $hauptadresse = $hauptobjekt->CRM_AdressenID;
        $sql = "INSERT INTO CRM_PERSONENLINK
                    (\"PersonID\", \"AdresseID\", \"AngelegtAm\")
                    VALUES(
                        '{$CRM_ADRESSEN_ID}',
                        '{$hauptadresse}',
                        getdate()
                    );";
        $stmt = sqlsrv_query($conn, $sql);
        if (!$stmt) {
            die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r(sqlsrv_errors(), true)));
        }
    };
    // Verknüpfungen löschen
// 	log_msg('$interessentenErpIdsToRemove=' . var_export($interessentenErpIdsToRemove, true));
    foreach ($interessentenErpIdsToRemove as $erpId) {
        $hauptobjekte = json_decode(getInteressentByErpId($erpId));
        if (count($hauptobjekte) == 1) {
            $hauptobjekt = $hauptobjekte[0];
        }
        if (!$hauptobjekt) {
            throw new Exception("Hauptobjekt mit INTERESS_ID #{$erpId}# nicht gefunden.");
        }
        $hauptadresse = $hauptobjekt->CRM_AdressenID;
        $sql = "DELETE FROM CRM_PERSONENLINK
                    WHERE \"PersonID\"='{$CRM_ADRESSEN_ID}'
                    AND \"AdresseID\"='{$hauptadresse}'
                    ;";
        $stmt = sqlsrv_query($conn, $sql);
        if (!$stmt) {
            die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r(sqlsrv_errors(), true)));
        }
    };
    
    
    // definitive Kontaktadresse holen zum Zurückgeben
    $aKontaktadressen = json_decode(getKontaktadresseByErpId($CRM_ADRESSEN_ID));
    if (count($aKontaktadressen) != 1) {
        throw new Exception("Kontaktadresse mit erpID #{$CRM_ADRESSEN_ID}# nicht gefunden.");
    }
    $kontaktadresse = $aKontaktadressen[0];
    
    // JSON Array zurückgeben
    return makeJsonFromArray($kontaktadresse);
}



