<?php
require_once('globalfunctions.inc.php');
require_once('makeArrayFromStmt.php');


$e->register('getMediaByItemErpId', [
		'erpId' => 'integer',
	], [
		'return' => 'string'
	],
	'Gibt die Bilder mit der Artikel-$erpId (ART_ID) zurück.'
);


/**
 * Gibt das Bild mit der $erpId (BILD_ID) zurück.
 * @param int $erpId ART_ID in der ERP-Datenbank
 * @return string JSON-String
 */
function getMediaByItemErpId($erpId)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($erpId="' . $erpId . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	
	$artikelnummer=getArtikelnummerByErpId($erpId);
	
	
	$sql = "SELECT	  B.*
			FROM dbo.BILD B
			WHERE B.Blobkey = 'AR" . escapeMssqlValue($artikelnummer) . "'
			ORDER BY B.Ordnung ASC";
	
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	
	
	$ArrRS=makeArrayFromStmt($stmt, function($meta, $name, $value, &$row){
		if( $name != 'Bild' ) return $row[$name];
		
		$tmpfname=tempnam(sys_get_temp_dir(), 'BILD');
		file_put_contents($tmpfname, $value);
		
		$contentsize=filesize($tmpfname);
		$contenttype=null;
		if(function_exists('finfo_open'))
		{
			$finfo = finfo_open(FILEINFO_MIME_TYPE);
			$contenttype=finfo_file($finfo, $tmpfname);
			finfo_close($finfo);
		} else if(function_exists('mime_content_type'))
		{
			$contenttype=mime_content_type($tmpfname);
		} else
		{
			$contenttype='application/octet-stream';
			log_msg('Mime-Typ kann nicht ermittelt werden.');
		}
		
		$row['contentsize']=$contentsize;
		$row['contenttype']=$contenttype;
		
		log_msg("Contenttype: {$contenttype} | Contentsize: {$contentsize}");
		
		unlink($tmpfname);
		return $row[$name];
	});
	
	
	
	
	
	// JSON Array zurückgeben
	return makeJsonFromArray($ArrRS);
}



