<?php
require_once('globalfunctions.inc.php');
require_once('makeArrayFromStmt.php');


$e->register('getPositionByErpId', [
		'erpId' => 'integer',
		'belegErpId' => 'integer',
	], [
		'return' => 'string',
	],
	'Gibt die Position mit der $erpId (BELEGP_ID) zurück.'
);


/**
 * Gibt die Position mit der $erpId (BELEGP_ID) zurück.
 * @param int $erpId BELEGP_ID in der ERP-Datenbank
 * @param int $belegErpId BELEG_ID in der ERP-Datenbank
 * @return string
 */
function getPositionByErpId($erpId, $belegErpId=null)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($erpId=' . var_export($erpId, true) . ', $belegErpId=' . var_export($belegErpId, true) . ')' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	if( is_array($erpId) && (count($erpId) > 0) ) $erpIdFilter="P.BELEGP_ID IN ('" . implode("', '", $erpId) . "')";
	else if( is_scalar($erpId) ) $erpIdFilter="P.BELEGP_ID = '" . escapeMssqlValue($erpId) . "'";
	else $erpIdFilter='1=1';
	
	if( is_array($belegErpId) && (count($belegErpId) > 0) ) $belegErpIdFilter="B.BELEG_ID IN ('" . implode("', '", $belegErpId) . "')";
	else if( is_scalar($belegErpId) ) $belegErpIdFilter="B.BELEG_ID = '" . escapeMssqlValue($belegErpId) . "'";
	else $belegErpIdFilter='1=1';
	
	
	$sql = "SELECT	  P.*
					, CONVERT(VARCHAR(10), P.Datum, 120) AS DatumConverted
					, TBP.TEXT AS TEXT
					, TBP.HTMLText as HTMLText
					, B.BELEG_ID
					, A.ART_ID
					, PP.BELEGP_ID as PARENT_BELEGP_ID
					, SUB_BELEGP_IDs=STUFF((SELECT CONCAT(';', SP.BELEGP_ID) FROM dbo.BELEGP  SP  WHERE SP.Hauptkennung = P.Kennung
						FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')
					
			FROM dbo.BELEGP  P
				LEFT JOIN dbo.TEXT   TBP  ON TBP.BLOBKEY=CONCAT('BP', P.Kennung)
				LEFT JOIN dbo.BELEG    B  ON B.Belegnummer = P.Belegnummer AND B.Belegtyp = P.Belegtyp
				LEFT JOIN dbo.ART      A  ON A.Artikelnummer = P.Artikelnummer
				LEFT JOIN dbo.BELEGP  PP  ON PP.Kennung = P.Hauptkennung
			WHERE {$erpIdFilter} AND {$belegErpIdFilter}
			ORDER BY P.Belegnummer, P.Postext";
	
// 	log_msg($sql);
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	return makeJsonFromStmt($stmt);
}




