<?php
require_once('globalfunctions.inc.php');

function removeCurly($str)
{
  return str_replace(['{', '}'], '', $str);
}

function addCurly($str)
{
  $str=removeCurly($str);
  if(empty($str)) return '';
  return '{' . $str . '}';
}



////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Liefert alle Daten einer Tabelle zurück
//  -> Tabelle = > MSSQL-Tabelle (z.b. dbo.CRM_ADRESSEN)
function sql_getData($tabelle)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($tabelle="' . $tabelle . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array(
		'Database' => $mssqlDB,
		'UID' => $mssqlUser,
		'PWD' => $mssqlPass,
		'CharacterSet' => 'UTF-8',
	);
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if ($tabelle == "") {
		log_msg("Fehler: Kein Tabellen-Name eingegeben");
		die("Fehler: Kein Tabellen-Name eingegeben");
	}
	
	$sql = "SELECT * FROM " . $tabelle;
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. ART_ID, Bezeichung, etc.
			$SpaltenTyp = $ArrFields[$i]['Type'];	// Varchar, Date, etc.
			
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			// SpaltenTyp -2 (TimeStamp) ausschliessen, alle anderen abarbeiten
			if ($SpaltenTyp != "-2") {
				$tmpArray[ $SpaltenName ] = $SpaltenWert;
			}
			
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}

	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}




/**
 * Holt über die stored procedure den nächsten Key.
 * @param string $blobKey
 * @param string $tableName
 * @param string $keyField
 * @return NULL|mixed
 */
function spNextAutoKey($blobKey, $tableName, $keyField)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($blobKey="' . $blobKey . '", $tableName="' . $tableName . '", $keyField="' . $keyField . '")' );
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	$sql = "DECLARE @aNewKey INT
			EXEC dbo.SL_spNextAutoKey N'$blobKey', N'$tableName', N'$keyField', @NewKey=@aNewKey OUTPUT
			SELECT @aNewKey AS NEWKEY;";
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	// NEWKEY ermitteln
	$NEWKEY=null;
	while( sqlsrv_next_result($stmt) )
		if( ($ret=sqlsrv_fetch_array($stmt, SQLSRV_FETCH_ASSOC)) && isset($ret['NEWKEY']) ) $NEWKEY=$ret['NEWKEY'];
	
	
	
	log_msg(__FUNCTION__ . '(): ' . '$NEWKEY="' . $NEWKEY . '"' );
	return $NEWKEY;
}




////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Liefert alle IDs zurück
//	-> DTvon = AngeletDatum von
//	-> DTbis = AngeletDatum bis (optional)
function findKundenByAngelegtDatum($DtVon, $DtBis)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($DtVon="' . $DtVon . '", $DtBis="' . $DtBis . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if ($DtVon == "") {
		die("Fehler: AngelegtVon-Datum fehlt!");
	}
	if ($DtBis == "") {
		$DtBis = date("Y-m-d H:i:s");
	}
	
		$sql = "SELECT dbo.DEBITOREN.KUNDEN_ID
				FROM dbo.DEBITOREN
				LEFT JOIN  dbo.CRM_ADRESSEN ON dbo.DEBITOREN.CRM_AdressenID = dbo.CRM_ADRESSEN.Id
				WHERE dbo.DEBITOREN.AngelegtAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND dbo.DEBITOREN.AngelegtAm <= CONVERT(datetime, '" . $DtBis . "', 120)
				ORDER BY dbo.DEBITOREN.AngelegtAm ASC";
	
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		$ArrRS[] = $row[0];
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//   -> Liefert alle IDs zurück
// Parameter
//	-> DTvon = BearbeitetAm  Datum "von"
//	-> DTbis = BearbeitetAm  Datum "bis" (optional)
function findKundenByBearbeitetDatum($DtVon, $DtBis)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($DtVon="' . $DtVon . '", $DtBis="' . $DtBis . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if ($DtVon == "") {
		die(log_msg("Fehler: BearbeitetAm Von-Datum fehlt!"));
	}
	if ($DtBis == "") {
		$DtBis = date("Y-m-d H:i:s");
	}
	
	
	$sql = "SELECT dbo.DEBITOREN.KUNDEN_ID
			FROM dbo.DEBITOREN
			LEFT JOIN dbo.CRM_ADRESSEN ON dbo.DEBITOREN.CRM_AdressenID = dbo.CRM_ADRESSEN.Id
			
			WHERE
			(
				dbo.DEBITOREN.BearbeitetAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND
				dbo.DEBITOREN.BearbeitetAm <= CONVERT(datetime, '" . $DtBis . "', 120)
			) OR (
				dbo.DEBITOREN.AngelegtAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND
				dbo.DEBITOREN.AngelegtAm <= CONVERT(datetime, '" . $DtBis . "', 120)
			)
			ORDER BY dbo.DEBITOREN.BearbeitetAm ASC";
	
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	// Array für Daten erstellen
	$ArrRS = array();
	
	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		$ArrRS[] = $row[0];
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}



////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//   -> Alle Kontakte eines Kunden zurückgeben
//	-> KundenNummer (z.b. 2010)
function getKundeKontakteByNummer($kundenNummer)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($kundenNummer="' . $kundenNummer . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	$sql = "SELECT dbo.DEBITOREN.KUNDEN_ID
					, dbo.DEBITOREN.Nummer
					, dbo.CRM_ADRESSEN.Vorname
					, dbo.CRM_ADRESSEN.Name
					, dbo.CRM_ADRESSEN.Strasse
					, dbo.CRM_ADRESSEN.Ort
					, dbo.CRM_ADRESSEN.Telefon1
					, dbo.CRM_ADRESSEN.Email
					, dbo.CRM_ADRESSEN.AngelegtAm
					, dbo.CRM_ADRESSEN.BearbeitetAm
			FROM dbo.DEBITOREN
				LEFT JOIN dbo.CRM_ADRESSEN ON dbo.DEBITOREN.CRM_AdressenID = dbo.CRM_ADRESSEN.Hauptadresse
			  WHERE dbo.DEBITOREN.Nummer = $kundenNummer
			  AND dbo.CRM_ADRESSEN.Name IS NOT NULL
			  AND dbo.CRM_ADRESSEN.Name NOT LIKE ''";
		  
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();
	
	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. KUNDEN_ID, Name, Vorname, ...
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			$tmpArray[ $SpaltenName ] = $SpaltenWert;
			
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//   -> Liefert alle LeistungsArtikel IDs zurück
//	-> DTvon = AngeletDatum von
//	-> DTbis = AngeletDatum bis (optional)
function findArtikelLeistungByAngelegtDatum($DtVon, $DtBis)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($DtVon="' . $DtVon . '", $DtBis="' . $DtBis . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
    if ($DtVon == "") {
		die("Fehler: AngelegtVon-Datum fehlt!");
	}
	if ($DtBis == "") {
		$DtBis = date("Y-m-d");
	}
	if( strlen($DtVon) != 10 || strlen($DtBis) != 10) {
		die("Fehler: Ung&uuml;ltiges Datum-Format");
	}
	
		  
	$sql = "SELECT dbo.ART.ART_ID
				FROM dbo.ART
				WHERE dbo.ART.Leistungsartikel = 'TRUE' AND CONVERT(VARCHAR(10), dbo.ART.AngelegtAm, 120) BETWEEN '" . $DtVon . "' AND '" . $DtBis . "'
				AND dbo.ART.Bezeichnung IS NOT NULL
				AND dbo.ART.Bezeichnung NOT LIKE ''";
			
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		$ArrRS[] = $row[0];
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// -> Liefert alle LeistungsArtikel IDs zurück
// -> DTvon = BearbeitetAm von
// -> DTbis = BearbeitetAm bis (optional)
function findArtikelLeistungByBearbeitetDatum($DtVon, $DtBis)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($DtVon="' . $DtVon . '", $DtBis="' . $DtBis . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if ($DtVon == "") {
		die("Fehler: AngelegtVon-Datum fehlt!");
	}
	if ($DtBis == "") {
		$DtBis = date("Y-m-d");
	}
	if( strlen($DtVon) != 10 || strlen($DtBis) != 10) {
		die("Fehler: Ung&uuml;ltiges Datum-Format");
	}
	
	
	$sql = "SELECT dbo.ART.ART_ID
				FROM dbo.ART
				WHERE dbo.ART.Leistungsartikel = 'TRUE' AND CONVERT(VARCHAR(10), dbo.ART.GeaendertAm, 120) BETWEEN '" . $DtVon . "' AND '" . $DtBis . "'
				AND dbo.ART.Bezeichnung IS NOT NULL
				AND dbo.ART.Bezeichnung NOT LIKE ''";
			
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		$ArrRS[] = $row[0];
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// -> Liefert LeistungsArtikel-Details zurück
// -> iD = ArtikelID
function getArtikelLeistungById($iD)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($iD="' . $iD . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	$sql = "SELECT dbo.ART.ART_ID
					,dbo.ART.Artikelnummer
					,dbo.ART.Bezeichnung
					,dbo.ART.AngelegtAm
					,dbo.ART.GeaendertAm
				FROM dbo.ART
				WHERE dbo.ART.Leistungsartikel = 'TRUE' AND dbo.ART.ART_ID = $iD
				AND dbo.ART.Bezeichnung IS NOT NULL
				AND dbo.ART.Bezeichnung NOT LIKE ''";
		  
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. KUNDEN_ID, Name, Vorname, ...
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			$tmpArray[ $SpaltenName ] = $SpaltenWert;
			
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//   -> Liefert LeistungsArtikel-Details zurück
//	-> artikelNummer = Artikelnummer
function getArtikelLeistungByNummer($artikelNummer)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($artikelNummer="' . $artikelNummer . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	$sql = "SELECT dbo.ART.ART_ID
					,dbo.ART.Artikelnummer
					,dbo.ART.Bezeichnung
					,dbo.ART.AngelegtAm
					,dbo.ART.GeaendertAm
				FROM dbo.ART
				WHERE dbo.ART.Leistungsartikel = 'TRUE' AND dbo.ART.Artikelnummer LIKE '$artikelNummer'
				AND dbo.ART.Bezeichnung IS NOT NULL
				AND dbo.ART.Bezeichnung NOT LIKE ''";
	
	// SQL-Abrage starten
	
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();
	
	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. ArtikelID_ID, Bezeichung, ...
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			$tmpArray[ $SpaltenName ] = $SpaltenWert;
			
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//   -> Liefert alle IDs zurück
//	-> DTvon = AngeletDatum von
//	-> DTbis = AngeletDatum bis (optional)
function findAuftragByAngelegtDatum($DtVon, $DtBis)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($DtVon="' . $DtVon . '", $DtBis="' . $DtBis . '")' );
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if ($DtVon == "") {
		die("Fehler: AngelegtVon-Datum fehlt!");
	}
	if ($DtBis == "") {
		$DtBis = date("Y-m-d H:i:s");
	}
	
	$sql = "SELECT dbo.BELEG.BELEG_ID
				FROM dbo.BELEG
				WHERE dbo.BELEG.Belegtyp = 'F'
				AND
				dbo.BELEG.AngelegtAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND
				dbo.BELEG.AngelegtAm <= CONVERT(datetime, '" . $DtBis . "', 120)
				ORDER BY dbo.BELEG.AngelegtAm ASC";
			
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		$ArrRS[] = $row[0];
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//   -> Liefert alle IDs zurück
//	-> DTvon = BearbeitetAm  Datum "von"
//	-> DTbis = BearbeitetAm  Datum "bis" (optional)
function findAuftragByBearbeitetDatum($DtVon, $DtBis)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($DtVon="' . $DtVon . '", $DtBis="' . $DtBis . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if ($DtVon == "") {
		die("Fehler: BearbeitetAm Von-Datum fehlt!");
	}
	if ($DtBis == "") {
		$DtBis = date("Y-m-d H:i:s");
	}

	$sql = "SELECT dbo.BELEG.BELEG_ID
			FROM dbo.BELEG
			WHERE dbo.BELEG.Belegtyp = 'F'
			AND
			( (
				dbo.BELEG.BearbeitetAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND
				dbo.BELEG.BearbeitetAm <= CONVERT(datetime, '" . $DtBis . "', 120)
			) OR (
				dbo.BELEG.AngelegtAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND
				dbo.BELEG.AngelegtAm <= CONVERT(datetime, '" . $DtBis . "', 120)
			) )
			ORDER BY dbo.BELEG.BearbeitetAm ASC";

	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		$ArrRS[] = $row[0];
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}



////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//   -> Liefert den Auftrag Status zurück
//	-> Belegnummer = Belegnummer
function getAuftragStatusVerrechnetByBelegnummer($Belegnummer, $iStatus=1)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($Belegnummer="' . $Belegnummer . '", $iStatus="' . $iStatus . '")' );
	
	
	return $iStatus;
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	$sql = "SELECT dbo.BELEG.BELEG_ID
					,dbo.BELEG.Belegnummer
					,dbo.BELEG.Belegtyp
					,dbo.BELEG.Status
					,dbo.BELEG.Erloes
					,dbo.BELEG.UebernahmeOffen
				FROM dbo.BELEG
				WHERE 
					( dbo.BELEG.Belegnummer = '$Belegnummer' AND dbo.BELEG.Belegtyp = 'F' ) 
					OR
					( dbo.BELEG.LieferBelegNr = '$Belegnummer' )";
		
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. KUNDEN_ID, Name, Vorname, ...
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			$tmpArray[ $SpaltenName ] = $SpaltenWert;
			
		}
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}


	// Anzahl Zeilen auslesen
	$numrows=count($ArrRS);

	// Status herausfinden
	foreach($ArrRS as $tmpArray)
	{
		if( $tmpArray['Belegnummer'] == $Belegnummer )
		{
			if($tmpArray['Belegtyp'] == 'R')
			{
				// Beleg ist eine Rechnung
//				if($tmpArray['Status'] == 3)		// Beleg ist MANUELL ERLEDIGT
//					$iStatus=1;
			} else
			{
				// Beleg ist keine Rechnung
				if(	($tmpArray['Erloes'] != 0)		// Beleg hat einen Wert
					&& ($tmpArray['Status'] < 2)	// Beleg ist nicht erledigt
				) $iStatus=0;

				if(	($tmpArray['Erloes'] == 0)		// Beleg hat keinen Wert
					&& ($numrows == 1)				// UND keine Folgebelege
					&& ($tmpArray['Status'] < 3)	// UND ist nicht MANUELL ERLEDIGT
				) $iStatus=0;

			}
		} else
		{
			$iStatus=getAuftragStatusVerrechnetByBelegnummer($tmpArray['Belegnummer'], $iStatus);
		}
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return $iStatus;
}



////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Liefert alle Projekt-IDs zurück
//	-> DTvon = AngeletDatum von
//	-> DTbis = AngeletDatum bis (optional)
function findProjekteByAngelegtDatum($DtVon, $DtBis)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($DtVon="' . $DtVon . '", $DtBis="' . $DtBis . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( __FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if ($DtVon == "") die(log_msg( __FUNCTION__ . '(): Error: AngelegtVon-Datum fehlt!' ));
	
	if ($DtBis == "") {
		$DtBis = date("Y-m-d H:i:s");
	}
	
	$sql = "SELECT dbo.WPROJEKT.WPROJEKT_ID
				FROM dbo.WPROJEKT
				WHERE
				dbo.WPROJEKT.AngelegtAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND
				dbo.WPROJEKT.AngelegtAm <= CONVERT(datetime, '" . $DtBis . "', 120)
				ORDER BY dbo.WPROJEKT.AngelegtAm ASC";
			
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		$ArrRS[] = $row[0];
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Liefert alle Projekt-IDs zurück
//	-> DTvon = AngeletDatum von
//	-> DTbis = AngeletDatum bis (optional)
function findProjekteByBearbeitetDatum($DtVon, $DtBis)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($DtVon="' . $DtVon . '", $DtBis="' . $DtBis . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( __FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if ($DtVon == "") die(log_msg( __FUNCTION__ . '(): Error: AngelegtVon-Datum fehlt!' ));
	
	if ($DtBis == "") {
		$DtBis = date("Y-m-d H:i:s");
	}
	
	$sql = "SELECT dbo.WPROJEKT.WPROJEKT_ID
			FROM dbo.WPROJEKT
			WHERE
			( (
				dbo.WPROJEKT.BearbeitetAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND
				dbo.WPROJEKT.BearbeitetAm <= CONVERT(datetime, '" . $DtBis . "', 120)
			) OR (
				dbo.WPROJEKT.AngelegtAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND
				dbo.WPROJEKT.AngelegtAm <= CONVERT(datetime, '" . $DtBis . "', 120)
			) )
			ORDER BY dbo.WPROJEKT.BearbeitetAm ASC";
	
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// Array für Daten erstellen
	$ArrRS = array();
	
	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		$ArrRS[] = $row[0];
	}
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//   -> Liefert Auftrag-Details zurück
//	-> iD = AuftragID
function getProjektByErpId($iD)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($iD="' . $iD . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( __FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	$sql = "SELECT dbo.WPROJEKT.WPROJEKT_ID
					,dbo.WPROJEKT.Id
					,dbo.WPROJEKT.Projekt
					,dbo.WPROJEKT.Status
					,dbo.WPROJEKT.Datum
					,dbo.WPROJEKT.Bezeichnung
					,dbo.WPROJEKT.Zusatz
					,dbo.WPROJEKT.Kunde
					,dbo.WPROJEKT.AngelegtAm
					,dbo.WPROJEKT.AngelegtVon
					,dbo.WPROJEKT.BearbeitetAm
					,dbo.WPROJEKT.BearbeitetVon
				FROM dbo.WPROJEKT
				WHERE dbo.WPROJEKT.WPROJEKT_ID = $iD";
	
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();
	
	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. KUNDEN_ID, Name, Vorname, ...
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			$tmpArray[ $SpaltenName ] = $SpaltenWert;
			
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}



/**
 * Findet Records in der Sync-Tabelle vom ERP
 * @param int $id		Letzte verarbeitete ID
 * @param int $limit	Anzahl zurückzugebender Records (0=unlimitiert)
 */
function findSyncEntries($id, $limit)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
// 	log_msg(__FUNCTION__ . '($id="' . $id . '", $limit="' . $limit . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( __FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if($limit > 0)
	{
		$sql = "SELECT TOP $limit *
					FROM ceRem3_sync
					WHERE id > $id
					ORDER BY id ASC
					";
	} else
	{
		$sql = "SELECT *
					FROM ceRem3_sync
					WHERE id > $id
					ORDER BY id ASC
					";
	}
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. KUNDEN_ID, Name, Vorname, ...
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			$tmpArray[ $SpaltenName ] = $SpaltenWert;
			
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}



/**
 * Löscht den Record aus der Sync-Tabelle vom ERP
 * @param int $id		Letzte verarbeitete ID
 */
function removeSyncEntry($id)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($id="' . $id . '")' );
	
	
	if(empty($id)) die(log_msg('$id can not be empty.'));
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( __FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	
	$sql = "DELETE
				FROM ceRem3_sync
				WHERE id = $id
				";
	
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	$rows_affected=sqlsrv_rows_affected($stmt);
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return $rows_affected;
}



/**
 * Setzt einen Record in der Sync-Tabelle vom ERP
 * @param string $cmd		Kommando
 * @param string $table		Tabelle
 * @param string $key		Primärschlüssel
 */
function setSyncEntry($cmd, $table, $key)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($cmd="' . $cmd . '"), $table="' . $table . '"), $key="' . $key . '")' );
	
	
	if(empty($cmd) || empty($table) || empty($key)) die(log_msg('Illegal parameters'));
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( __FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	
	$sql = "INSERT
				INTO ceRem3_sync
				(\"command\", \"table\", \"key\", \"datum\")
				VALUES ('$cmd', '$table', '$key', GETDATE());
				SELECT SCOPE_IDENTITY();";
	
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	sqlsrv_next_result($stmt);
	sqlsrv_fetch($stmt);
	$last_insert_id=sqlsrv_get_field($stmt, 0);
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return $last_insert_id;
}



/**
 * Neutralisiert einen Record in der Sync-Tabelle vom ERP
 * @param string $cmd		Kommando
 * @param string $table		Tabelle
 * @param string $key		Primärschlüssel
 */
function unsetSyncEntry($cmd, $table, $key)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($cmd="' . $cmd . '", $table="' . $table . '", $key="' . $key . '")' );
	
	
	if(empty($table) || empty($key)) die(log_msg('Illegal parameters'));
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( __FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if(empty($cmd))
	{
		$sql = "UPDATE
					ceRem3_sync
					SET \"command\"='NOOP'
					WHERE
					\"table\"='$table'
					AND \"key\"='$key';
					SELECT SCOPE_IDENTITY();";
	} else
	{
		$sql = "UPDATE
					ceRem3_sync
					SET \"command\"='NOOP'
					WHERE
					\"command\"='$cmd'
					AND \"table\"='$table'
					AND \"key\"='$key';
					SELECT SCOPE_IDENTITY();";
	}
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	sqlsrv_next_result($stmt);
	sqlsrv_fetch($stmt);
	$last_insert_id=sqlsrv_get_field($stmt, 0);
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	// JSON Array zurückgeben
	return $last_insert_id;
}





/**
 * Gibt ART_IDs von Artikeln zurück, die zwischen $DtVon und $DtBis angelegt wurden.
 * @param string $DtVon
 * @param string $DtBis
 * @return string
 */
function findItemsByAngelegtDatum($DtVon, $DtBis)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($DtVon="' . $DtVon . '", $DtBis="' . $DtBis . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if ($DtVon == "") {
		die("Fehler: AngelegtVon-Datum fehlt!");
	}
	if ($DtBis == "") {
		$DtBis = date("Y-m-d H:i:s");
	}
	
		$sql = "SELECT dbo.ART.ART_ID
				FROM dbo.ART
				WHERE
					dbo.ART.AngelegtAm > CONVERT(datetime, '" . $DtVon . "', 120)
					AND
					dbo.ART.AngelegtAm <= CONVERT(datetime, '" . $DtBis . "', 120)
				ORDER BY dbo.ART.AngelegtAm ASC";
	
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		$ArrRS[] = $row[0];
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


/**
 * Gibt ART_IDs von Artikeln zurück, die zwischen $DtVon und $DtBis bearbeitet wurden.
 * @param string $DtVon
 * @param string $DtBis
 * @return string
 */
function findItemsByBearbeitetDatum($DtVon, $DtBis)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($DtVon="' . $DtVon . '", $DtBis="' . $DtBis . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	if ($DtVon == "") {
		die(log_msg("Fehler: BearbeitetAm Von-Datum fehlt!"));
	}
	if ($DtBis == "") {
		$DtBis = date("Y-m-d H:i:s");
	}
	
	
	$sql = "SELECT dbo.ART.ART_ID
			FROM dbo.ART
			
			WHERE
			(
				dbo.ART.GeaendertAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND
				dbo.ART.GeaendertAm <= CONVERT(datetime, '" . $DtBis . "', 120)
			) OR (
				dbo.ART.AngelegtAm > CONVERT(datetime, '" . $DtVon . "', 120)
				AND
				dbo.ART.AngelegtAm <= CONVERT(datetime, '" . $DtBis . "', 120)
			)
			ORDER BY dbo.ART.GeaendertAm ASC";
	
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	// Array für Daten erstellen
	$ArrRS = array();
	
	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		$ArrRS[] = $row[0];
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}




/**
 * Gibt den Preis mit der $erpId (ARPREIS_ID) zurück.
 * @param int $erpId
 * @return string
 */
function getPreisByErpId($erpId)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($erpId="' . $erpId . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	$sql = "SELECT dbo.ARPREIS.ARPREIS_ID
					, dbo.ARPREIS.Artikelnummer
					, dbo.ARPREIS.Preistyp
					, dbo.ARPREIS.TypNummer
					, dbo.ARPREIS.Waehrung
					, dbo.ARPREIS.VonDatum
					, dbo.ARPREIS.Menge
					, dbo.ARPREIS.BisDatum
					, dbo.ARPREIS.Preis
					, dbo.ARPREIS.Steuertyp
					, dbo.ARPREIS.Bemerkung
					, dbo.ARPREIS.GeaendertAm
					, dbo.ARPREIS.GeaendertVon
			FROM dbo.ARPREIS
			WHERE dbo.ARPREIS.ARPREIS_ID = '$erpId'";
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. KUNDEN_ID, Name, Vorname, ...
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			$tmpArray[ $SpaltenName ] = $SpaltenWert;
			
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


/**
 * Gibt die Rabattgruppe mit der $erpId (ARPREIS_ID) zurück.
 * @param int $erpId
 * @return string
 */
function getRabattgruppeByErpId($erpId)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($erpId="' . $erpId . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	$sql = "SELECT dbo.RABGRUP.RABGRUP_ID
					, dbo.RABGRUP.Rabattgruppe
					, dbo.RABGRUP.Rabattyp
					, dbo.RABGRUP.Nummer
					, dbo.RABGRUP.Preisgruppe
					, dbo.RABGRUP.Mengenrabatt
					, dbo.RABGRUP.Rabatt
					, dbo.RABGRUP.Rabatt2
					, dbo.GRUPPEN.Bezeichnung
					, dbo.GRUPPEN.Zusatz
			FROM dbo.RABGRUP
			LEFT JOIN dbo.GRUPPEN ON dbo.GRUPPEN.Nummer=dbo.RABGRUP.Rabattgruppe AND dbo.GRUPPEN.Id='RG'
			WHERE dbo.RABGRUP.RABGRUP_ID = '$erpId'";
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. KUNDEN_ID, Name, Vorname, ...
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			$tmpArray[ $SpaltenName ] = $SpaltenWert;
			
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


/**
 * Gibt das Zubehoer mit der $erpId (ZUBEHOER_ID) zurück.
 * @param int $erpId
 * @return string
 */
function getZubehoerByErpId($erpId)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($erpId="' . $erpId . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	$sql = "SELECT dbo.ZUBEHOER.ZUBEHOER_ID
					, dbo.ZUBEHOER.ArtArtikelnummer
					, dbo.ZUBEHOER.Pos
					, dbo.ZUBEHOER.Artikelnummer
					, dbo.ZUBEHOER.Mengenformel
					, dbo.ZUBEHOER.Mengeneinheit
					, dbo.ZUBEHOER.Preisgruppe
					, dbo.ZUBEHOER.Mengenaktualisierung
					, dbo.ZUBEHOER.Einfuegemodus
					, dbo.ZUBEHOER.Verwendung
					, dbo.ZUBEHOER.AngelegtAm
					, dbo.ZUBEHOER.AngelegtVon
					, dbo.ZUBEHOER.BearbeitetAm
					, dbo.ZUBEHOER.BearbeitetVon
			FROM dbo.ZUBEHOER
			WHERE dbo.ZUBEHOER.ZUBEHOER_ID = '$erpId'";
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. KUNDEN_ID, Name, Vorname, ...
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			$tmpArray[ $SpaltenName ] = $SpaltenWert;
			
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}


/**
 * Gibt das Zubehoer mit der $artikelnummer zurück.
 * @param int $erpId
 * @return string
 */
function getZubehoerByArtikelnummer($artikelnummer)
{
	global $mssqlServer, $mssqlInstanz, $mssqlUser, $mssqlPass, $mssqlDB;
	
	log_msg(__FUNCTION__ . '($artikelnummer="' . $artikelnummer . '")' );
	
	
	$serverName = $mssqlServer . "\\" . $mssqlInstanz;
	$connectionInfo = array( "Database"=>$mssqlDB, "UID"=>$mssqlUser, "PWD"=>$mssqlPass, "CharacterSet"=>"UTF-8");
	$conn = sqlsrv_connect( $serverName, $connectionInfo);
	if( !$conn ) die(log_msg( 'MSSQL Error: ' . print_r( sqlsrv_errors(), true) ));
	
	
	$sql = "SELECT dbo.ZUBEHOER.ZUBEHOER_ID
					, dbo.ZUBEHOER.ArtArtikelnummer
					, dbo.ZUBEHOER.Pos
					, dbo.ZUBEHOER.Artikelnummer
					, dbo.ZUBEHOER.Mengenformel
					, dbo.ZUBEHOER.Mengeneinheit
					, dbo.ZUBEHOER.Preisgruppe
					, dbo.ZUBEHOER.Mengenaktualisierung
					, dbo.ZUBEHOER.Einfuegemodus
					, dbo.ZUBEHOER.Verwendung
					, dbo.ZUBEHOER.AngelegtAm
					, dbo.ZUBEHOER.AngelegtVon
					, dbo.ZUBEHOER.BearbeitetAm
					, dbo.ZUBEHOER.BearbeitetVon
			FROM dbo.ZUBEHOER
			WHERE dbo.ZUBEHOER.ArtArtikelnummer = '$artikelnummer'";
	
	// SQL-Abrage starten
	$stmt = sqlsrv_query( $conn, $sql );
	if(!$stmt) die(log_msg('MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	
	
	// SQL-Felddefinitionen laden
	$ArrFields = sqlsrv_field_metadata($stmt);
	
	// Array für Daten erstellen
	$ArrRS = array();

	// Alle Datensätze abarbeiten
	while( $row = sqlsrv_fetch_array( $stmt, SQLSRV_FETCH_NUMERIC) ) {
		
		// Array für Datensatz
		$tmpArray = array();
		
		// Für jeden Datensatz -> Alle Felder (Spalten)
		for ($i = 0; $i < count($ArrFields); $i++) {
			$SpaltenName = $ArrFields[$i]['Name'];	// Spaltenname (z.B. KUNDEN_ID, Name, Vorname, ...
			$SpaltenWert = $row[$i];				// Datennsatz-Wert
			
			$tmpArray[ $SpaltenName ] = $SpaltenWert;
			
		}
		
		// Datensatz in Array für Daten laden
		$ArrRS[] = $tmpArray;
	}
	
	
	// SQL-Verbindung trennen
	sqlsrv_close($conn);
	
	
	// JSON Array zurückgeben
	return json_encode($ArrRS);
}






