<?php



/**
 * Wert escapen für MSSQL.
 * @param string $str
 * @return string
 */
function escapeMssqlValue($str)
{
	return str_replace("'", "''", $str);
}


/**
 * Feldliste erstellen aus den Attributen des Objekts.
 * @param stdObject $obj Objekt.
 * @return string
 */
function makeMssqlFieldlist($obj, $filter=null)
{
	$vars=[];
	foreach(get_object_vars($obj) as $name => $val)
		if( !is_array($filter) || in_array($name, $filter) ) $vars[$name]=$val;
	$str=implode('", "', array_keys($vars));
	if(trim($str) != '') $str='"' . $str . '"';
	return '(' . $str . ')';
}


/**
 * Wertliste erstellen aus den Attributen des Objekts.
 * @param stdObject $obj Objekt.
 * @return string
 */
function makeMssqlValuelist($obj, $filter=null)
{
	$vars=[];
	foreach(get_object_vars($obj) as $name => $val)
		if( !is_array($filter) || in_array($name, $filter) ) $vars[$name]=escapeMssqlValue($val);
	$str=implode("', '", array_values($vars));
	if(trim($str) != '') $str="'" . $str . "'";
	return '(' . $str . ')';
}


/**
 * SET-Liste erstellen aus den Attributen des Objekts.
 * @param stdObject $obj Objekt.
 * @return string
 */
function makeMssqlSetlist($obj, $filter=null)
{
	$vars=[];
	foreach(get_object_vars($obj) as $name => $val)
		if( !is_array($filter) || in_array($name, $filter) ) $vars[$name]=escapeMssqlValue($val);
	$aSet=[];
	foreach($vars as $name => $val) $aSet[]="\"{$name}\"='{$val}'";
	return implode(', ', $aSet);
}



/**
 * Gibt die zuletzt erstelle ID zurück.
 * @param mixed $stmt Statement Resource.
 * @return string
 */
function mssqlLastInsertId($stmt)
{
	$ID=null;
	while( sqlsrv_next_result($stmt) )
		if( ($ret=sqlsrv_fetch_array($stmt, SQLSRV_FETCH_ASSOC)) && isset($ret['LAST_INSERT_ID']) ) $ID=$ret['LAST_INSERT_ID'];
	return $ID;
}



/**
 * Gibt ein Array der gültigen Spalten (ohne Identitäts-Spalte) einer Tabelle zurück.
 * @param string $tablename
 * @param mixed $conn
 * @return array
 */
function mssqlTableFields($tablename, $conn)
{
	$sql="
		SELECT *, COLUMNPROPERTY(object_id(TABLE_SCHEMA+'.'+TABLE_NAME), COLUMN_NAME, 'IsIdentity') AS IsIdentity
		FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA=? AND TABLE_NAME=? ORDER BY ORDINAL_POSITION;
	";
	$stmt=sqlsrv_query($conn, $sql, ['dbo', $tablename]);
	if(!$stmt) die(log_msg(__FUNCTION__ . '(): MSSQL Error: ' . print_r( sqlsrv_errors(), true)));
	$a=makeArrayFromStmt($stmt);
	$aColumns=[];
	foreach($a as $aRow) if( $aRow['IsIdentity'] != 1 ) $aColumns[]=$aRow['COLUMN_NAME'];
	//log_msg('$aColumns=' . print_r($aColumns, true));
	return $aColumns;
}



